atomate.feff.workflows package
==============================

Submodules
----------

atomate.feff.workflows.eels module
----------------------------------

.. automodule:: atomate.feff.workflows.eels
    :members:
    :undoc-members:
    :show-inheritance:

atomate.feff.workflows.xas module
---------------------------------

.. automodule:: atomate.feff.workflows.xas
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: atomate.feff.workflows
    :members:
    :undoc-members:
    :show-inheritance:
